@@ -3,8 +3,9 @@ import os
 import click
 from rich.console import Console
 
-from services.commands.services import webcli
+from services.commands.web import webcli
 from services.commands.manager import managercli
+from services.commands.common import startproject
 
 
 def init_cli():
@@ -29,6 +30,7 @@ def init_cli():
     cli.add_command(version)
     cli.add_command(webcli)
     cli.add_command(managercli)
+    cli.add_command(startproject)
     return cli
 
 
