@@ -1,6 +1,8 @@
 from abc import ABC, abstractmethod
 from typing import Any, Dict, List, Optional, Union
 
+from sanic import Request
+
 from .types import JWTResponse
 
 
@@ -17,10 +19,6 @@ class TokenStoreSpec(ABC):
     async def delete(self, key: str):
         pass
 
-    # @abstractmethod
-    # async def validate(self, token: str, user: str) -> bool:
-    #     pass
-
     @staticmethod
     @abstractmethod
     def generate(sign: Optional[str] = None) -> str:
@@ -56,3 +54,4 @@ class AuthSpec(ABC):
     @abstractmethod
     async def store_refresh_token(self, username: str) -> str:
         pass
+
